HAL Conditional Density Estimation in a Cross-validation Fold
cv_haldensify(
fold,
long_data,
wts = rep(1, nrow(long_data)),
lambda_seq = exp(seq(-1, -13, length = 1000L)),
smoothness_orders = 0L,
...
)A list, containing density predictions, observations IDs,
observation-level weights, and cross-validation indices for conditional
density estimation on a single fold of the overall data.
Object specifying cross-validation folds as generated by a call
to make_folds.
A data.table or data.frame object containing
the data in long format, as given in diaz2011superhaldensify,
as produced by format_long_hazards.
A numeric vector of observation-level weights, matching in
its length the number of records present in the long format data. Default
is to weight all observations equally.
A numeric sequence of values of the regularization
parameter of Lasso regression; passed to fit_hal.
A integer indicating the smoothness of the
HAL basis functions; passed to fit_hal. The default
is set to zero, for indicator basis functions.
Additional (optional) arguments of fit_hal
that may be used to control fitting of the HAL regression model. Possible
choices include use_min, reduce_basis, return_lasso,
and return_x_basis, but this list is not exhaustive. Consult the
documentation of fit_hal for complete details.
Estimates the conditional density of A|W for a subset of the full
set of observations based on the inputted structure of the cross-validation
folds. This is a helper function intended to be used to select the optimal
value of the penalization parameter for the highly adaptive lasso estimates
of the conditional hazard (via cross_validate). The