Learn R Programming

haldensify (version 0.2.8)

print.haldensify: Print: Highly Adaptive Lasso Conditional Density Estimates

Description

Print: Highly Adaptive Lasso Conditional Density Estimates

Usage

# S3 method for haldensify
print(x, ...)

Value

None. Called for the side effect of printing an informative summary of slots of objects of class haldensify.

Arguments

x

An object of class haldensify.

...

Other options (not currently used).

Details

The print method for objects of class haldensify

Examples

Run this code
# simulate data: W ~ U[-4, 4] and A|W ~ N(mu = W, sd = 0.5)
set.seed(11249)
n_train <- 50
w <- runif(n_train, -4, 4)
a <- rnorm(n_train, w, 0.5)

# learn relationship A|W using HAL-based density estimation procedure
haldensify_fit <- haldensify(
  A = a, W = w, n_bins = c(3, 5),
  lambda_seq = exp(seq(-1, -15, length = 50L)),
  max_degree = 2, smoothness_orders = 0, reduce_basis = 0.1
)
print(haldensify_fit)

Run the code above in your browser using DataLab